# helloworld-jms: Helloworld JMS Example - adapted for Apache BZ 61142

Author: Joerg Baesner
original Author: Weston Price  
Level: Intermediate  
Technologies: JMS  

## System Requirements

The application this project produces is designed to be run on Wildfly nightly build or later.

The Wildfly nightly can be downloaded from:
https://ci.wildfly.org/guestAuth/repository/download/WF_Nightly/latest.lastFinished/wildfly-11.0.0.Beta1-SNAPSHOT.zip

Once unzipped, copy the 'jboss-client.jar' of Wildfly to the 'lib' folder of this project...

All you need to build this project is Maven.

## Use of ${jboss.home.name}

In the following instructions, replace `${jboss.home.name}` with the actual path to your Wildfly installation. 


## Add an Application User

This project uses secured management interfaces and requires that you create the following application user to access the running application.

| **UserName** | **Realm** | **Password** | **Roles** |
|:-----------|:-----------|:-----------|:-----------|
| quickstartUser| ApplicationRealm | quickstartPwd1!| guest |

To add the application user, open a command prompt and type the following command:

        For Linux:   ${jboss.home.name}/bin/add-user.sh -a -u 'quickstartUser' -p 'quickstartPwd1!' -g 'guest'
        
## Configure the Server

You configure the JMS `test` queue by running JBoss CLI commands. For your convenience, this project batches the commands into a `configure-jms.cli` script provided in the root directory of this project. In addition this script also configures the required 'client-mapping' on the 'http' socket-binding.

After applying the script the client-mapping will point to 'localhost:8282'.

1. Start the Wildfly server by typing the following:

        For Linux:  ${jboss.home.name}/bin/standalone.sh -c standalone-full.xml --admin-only

2. Open a new command prompt, navigate to the root directory of this project, and run the following command, replacing ${jboss.home.name} with the path to your server:

        For Linux: ${jboss.home.name}/bin/jboss-cli.sh --connect --file=configure-jms.cli
 
3. You should see the following result when you run the script:

        The batch executed successfully
        process-state: reload-required 
        
4. Stop the Wildfly server.

## Start the Server with the Full Profile

1. Open a command prompt and navigate to the root of the Wildfly directory.
2. The following shows the command line to start the server with the full profile:

        For Linux:   ${jboss.home.name}/bin/standalone.sh -c standalone-full.xml


## Build and Execute the Project

To run the project from the command line:

1. Make sure you have started the Wildfly server. See the instructions in the previous section.

2. Open a command prompt and navigate to the root of the helloworld-jms directory:

        cd PATH_TO/helloworld-jms

3. Type the following command to compile and execute the quickstart:

        mvn clean compile exec:java

## Investigate the Console Output

Without having an Apache listening on port '8282' the output will be:

[INFO] --- exec-maven-plugin:1.6.0:java (default-cli) @ helloworld-jms ---
Jul 03, 2017 2:58:01 PM org.wildfly.naming.client.Version <clinit>
INFO: WildFly Naming version 1.0.0.Beta15
Jul 03, 2017 2:58:01 PM org.jboss.as.quickstarts.jms.HelloWorldJMSClient main
INFO: Attempting to acquire connection factory "jms/RemoteConnectionFactory"
Jul 03, 2017 2:58:01 PM org.xnio.Xnio <clinit>
INFO: XNIO version 3.5.0.Beta6
Jul 03, 2017 2:58:01 PM org.xnio.nio.NioXnio <clinit>
INFO: XNIO NIO Implementation Version 3.5.0.Beta6
Jul 03, 2017 2:58:01 PM org.jboss.remoting3.EndpointImpl <clinit>
INFO: JBoss Remoting version 5.0.0.Beta24
Jul 03, 2017 2:58:01 PM org.wildfly.security.Version <clinit>
INFO: ELY00001: WildFly Elytron version 1.1.0.Beta47
Jul 03, 2017 2:58:02 PM org.jboss.as.quickstarts.jms.HelloWorldJMSClient main
INFO: Found connection factory "jms/RemoteConnectionFactory" in JNDI
Jul 03, 2017 2:58:02 PM org.jboss.as.quickstarts.jms.HelloWorldJMSClient main
INFO: Attempting to acquire destination "jms/queue/test"
Jul 03, 2017 2:58:02 PM org.jboss.as.quickstarts.jms.HelloWorldJMSClient main
INFO: Found destination "jms/queue/test" in JNDI
[WARNING] 
javax.jms.JMSRuntimeException: Failed to create session factory
	at org.apache.activemq.artemis.jms.client.JmsExceptionUtils.convertToRuntimeException(JmsExceptionUtils.java:88)
	at org.apache.activemq.artemis.jms.client.ActiveMQConnectionFactory.createContext(ActiveMQConnectionFactory.java:292)
	at org.apache.activemq.artemis.jms.client.ActiveMQConnectionFactory.createContext(ActiveMQConnectionFactory.java:280)
	at org.jboss.as.quickstarts.jms.HelloWorldJMSClient.main(HelloWorldJMSClient.java:75)
	at sun.reflect.NativeMethodAccessorImpl.invoke0(Native Method)
	at sun.reflect.NativeMethodAccessorImpl.invoke(NativeMethodAccessorImpl.java:62)
	at sun.reflect.DelegatingMethodAccessorImpl.invoke(DelegatingMethodAccessorImpl.java:43)
	at java.lang.reflect.Method.invoke(Method.java:498)
	at org.codehaus.mojo.exec.ExecJavaMojo$1.run(ExecJavaMojo.java:282)
	at java.lang.Thread.run(Thread.java:748)
Caused by: javax.jms.JMSException: Failed to create session factory
	at org.apache.activemq.artemis.jms.client.ActiveMQConnectionFactory.createConnectionInternal(ActiveMQConnectionFactory.java:757)
	at org.apache.activemq.artemis.jms.client.ActiveMQConnectionFactory.createContext(ActiveMQConnectionFactory.java:287)
	... 8 more
Caused by: ActiveMQNotConnectedException[errorType=NOT_CONNECTED message=AMQ119007: Cannot connect to server(s). Tried with all available servers.]
	at org.apache.activemq.artemis.core.client.impl.ServerLocatorImpl.createSessionFactory(ServerLocatorImpl.java:787)
	at org.apache.activemq.artemis.jms.client.ActiveMQConnectionFactory.createConnectionInternal(ActiveMQConnectionFactory.java:755)
	... 9 more


## Setup Apache

1. Setup an Apache instance listening on port '8282', including the patch for 'https://issues.jboss.org/browse/JBCS-254'
   acting as a proxy using 'mod_proxy_wstunnel'.

2. Type the following command to compile and execute the quickstart:

        mvn clean compile exec:java

## Investigate the Console Output

[INFO] --- exec-maven-plugin:1.6.0:java (default-cli) @ helloworld-jms ---
Jul 03, 2017 3:02:26 PM org.wildfly.naming.client.Version <clinit>
INFO: WildFly Naming version 1.0.0.Beta15
Jul 03, 2017 3:02:26 PM org.jboss.as.quickstarts.jms.HelloWorldJMSClient main
INFO: Attempting to acquire connection factory "jms/RemoteConnectionFactory"
Jul 03, 2017 3:02:26 PM org.xnio.Xnio <clinit>
INFO: XNIO version 3.5.0.Beta6
Jul 03, 2017 3:02:26 PM org.xnio.nio.NioXnio <clinit>
INFO: XNIO NIO Implementation Version 3.5.0.Beta6
Jul 03, 2017 3:02:26 PM org.jboss.remoting3.EndpointImpl <clinit>
INFO: JBoss Remoting version 5.0.0.Beta24
Jul 03, 2017 3:02:26 PM org.wildfly.security.Version <clinit>
INFO: ELY00001: WildFly Elytron version 1.1.0.Beta47
javax.naming.CommunicationException: WFNAM00018: Failed to connect to remote host [Root exception is java.net.ConnectException: Connection refused]
	at org.wildfly.naming.client.remote.RemoteNamingProvider.getPeerIdentityForNaming(RemoteNamingProvider.java:73)
	at org.wildfly.naming.client.remote.RemoteContext.lambda$lookupNative$0(RemoteContext.java:109)
	at org.wildfly.naming.client.NamingProvider.performExceptionAction(NamingProvider.java:115)
	at org.wildfly.naming.client.remote.RemoteContext.lookupNative(RemoteContext.java:108)
	at org.wildfly.naming.client.AbstractFederatingContext.lookup(AbstractFederatingContext.java:78)
	at org.wildfly.naming.client.AbstractFederatingContext.lookup(AbstractFederatingContext.java:64)
	at org.wildfly.naming.client.WildFlyRootContext.lookup(WildFlyRootContext.java:153)
	at javax.naming.InitialContext.lookup(InitialContext.java:417)
	at org.jboss.as.quickstarts.jms.HelloWorldJMSClient.main(HelloWorldJMSClient.java:64)
	at sun.reflect.NativeMethodAccessorImpl.invoke0(Native Method)
	at sun.reflect.NativeMethodAccessorImpl.invoke(NativeMethodAccessorImpl.java:62)
	at sun.reflect.DelegatingMethodAccessorImpl.invoke(DelegatingMethodAccessorImpl.java:43)
	at java.lang.reflect.Method.invoke(Method.java:498)
	at org.codehaus.mojo.exec.ExecJavaMojo$1.run(ExecJavaMojo.java:282)
	at java.lang.Thread.run(Thread.java:748)
Caused by: java.net.ConnectException: Connection refused
	at sun.nio.ch.SocketChannelImpl.checkConnect(Native Method)
	at sun.nio.ch.SocketChannelImpl.finishConnect(SocketChannelImpl.java:717)
	at org.xnio.nio.WorkerThread$ConnectHandle.handleReady(WorkerThread.java:321)
	at org.xnio.nio.WorkerThread.run(WorkerThread.java:567)
	at ...asynchronous invocation...(Unknown Source)
	at org.jboss.remoting3.EndpointImpl.connect(EndpointImpl.java:545)
	at org.jboss.remoting3.EndpointImpl.connect(EndpointImpl.java:513)
	at org.jboss.remoting3.ConnectionInfo$None.getConnection(ConnectionInfo.java:84)
	at org.jboss.remoting3.ConnectionInfo.getConnection(ConnectionInfo.java:57)
	at org.jboss.remoting3.EndpointImpl.doGetConnection(EndpointImpl.java:464)
	at org.jboss.remoting3.EndpointImpl.getConnectedIdentity(EndpointImpl.java:410)
	at org.jboss.remoting3.UncloseableEndpoint.getConnectedIdentity(UncloseableEndpoint.java:55)
	at org.wildfly.naming.client.remote.SingleRemoteNamingProvider.lambda$new$0(SingleRemoteNamingProvider.java:86)
	at java.security.AccessController.doPrivileged(Native Method)
	at org.wildfly.naming.client.remote.SingleRemoteNamingProvider.getFuturePeerIdentity(SingleRemoteNamingProvider.java:121)
	at org.wildfly.naming.client.remote.SingleRemoteNamingProvider.getPeerIdentity(SingleRemoteNamingProvider.java:110)
	at org.wildfly.naming.client.remote.RemoteNamingProvider.getPeerIdentityForNaming(RemoteNamingProvider.java:69)
	... 14 more

Here it fails, as the 2nd upgrade is not done...
